# ChronoSheetsAPI

## Requirements

Building the API client library requires [Maven](https://maven.apache.org/) to be installed.

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn deploy
```

Refer to the [official documentation](https://maven.apache.org/plugins/maven-deploy-plugin/usage.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
    <groupId>com.chronosheets.api.android</groupId>
    <artifactId>ChronoSheetsAPI</artifactId>
    <version>1.0.0</version>
    <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
compile "com.chronosheets.api.android:ChronoSheetsAPI:1.0.0"
```

### Others

At first generate the JAR by executing:

    mvn package

Then manually install the following JARs:

- target/ChronoSheetsAPI-1.0.0.jar
- target/lib/*.jar

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

import ChronoSheetsClientLibApi.AggregateClientProjectsApi;

public class AggregateClientProjectsApiExample {

    public static void main(String[] args) {
        AggregateClientProjectsApi apiInstance = new AggregateClientProjectsApi();
        try {
            AggregateClientListApiResponse result = apiInstance.aggregateClientProjectsGetAggregateClientProjectsGet();
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling AggregateClientProjectsApi#aggregateClientProjectsGetAggregateClientProjectsGet");
            e.printStackTrace();
        }
    }
}

```

## Documentation for API Endpoints

All URIs are relative to *https://api.chronosheets.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AggregateClientProjectsApi* | [**aggregateClientProjectsGetAggregateClientProjectsGet**](docs/AggregateClientProjectsApi.md#aggregateClientProjectsGetAggregateClientProjectsGet) | **GET** /AggregateClientProjects/GetAggregateClientProjects | Get client and project information, aggregated.    Requires the &#39;SubmitTimesheets&#39; or &#39;ManageClientsAndProjects&#39; permissions.
*AggregateJobTasksApi* | [**aggregateJobTasksGetAggregateJobTasksGet**](docs/AggregateJobTasksApi.md#aggregateJobTasksGetAggregateJobTasksGet) | **GET** /AggregateJobTasks/GetAggregateJobTasks | Get jobs and tasks information, aggregated.    Requires the &#39;SubmitTimesheets&#39; or &#39;ManageJobsAndTask&#39; permissions.
*ClientsApi* | [**clientsCreateClientPost**](docs/ClientsApi.md#clientsCreateClientPost) | **POST** /Clients/CreateClient | Create a client.    Requires the &#39;ManageClientsAndProjects&#39; permission.
*ClientsApi* | [**clientsGetClientGet**](docs/ClientsApi.md#clientsGetClientGet) | **GET** /Clients/GetClient | Get a particular client.    Requires the &#39;ManageClientsAndProjects&#39; or &#39;ManageJobsAndTask&#39; permissions.
*ClientsApi* | [**clientsGetClientsGet**](docs/ClientsApi.md#clientsGetClientsGet) | **GET** /Clients/GetClients | Get a collection of clients that are under your organisation.    Requires the &#39;ManageClientsAndProjects&#39; or &#39;ManageJobsAndTask&#39; permissions.
*ClientsApi* | [**clientsUpdateClientPut**](docs/ClientsApi.md#clientsUpdateClientPut) | **PUT** /Clients/UpdateClient | Update a client.    Requires the &#39;ManageClientsAndProjects&#39; permission.
*FileAttachmentsApi* | [**fileAttachmentsDeleteTimesheetFileAttachmentDelete**](docs/FileAttachmentsApi.md#fileAttachmentsDeleteTimesheetFileAttachmentDelete) | **DELETE** /FileAttachments/DeleteTimesheetFileAttachment | Delete a particular timesheet file attachment  Requires the &#39;SubmitTimesheets&#39; permission.
*FileAttachmentsApi* | [**fileAttachmentsGetFileAttachmentByIdGet**](docs/FileAttachmentsApi.md#fileAttachmentsGetFileAttachmentByIdGet) | **GET** /FileAttachments/GetFileAttachmentById | Get a particular file attachment by ID.  User must own the file attachment for access.
*FileAttachmentsApi* | [**fileAttachmentsGetMyFileAttachmentsGet**](docs/FileAttachmentsApi.md#fileAttachmentsGetMyFileAttachmentsGet) | **GET** /FileAttachments/GetMyFileAttachments | Get my file attachments.  Get files you&#39;ve attached to timesheets.
*FleetApi* | [**fleetCreateVehiclePost**](docs/FleetApi.md#fleetCreateVehiclePost) | **POST** /Fleet/CreateVehicle | Create a vehicle.    Requires the &#39;ManageFleet&#39; permission.
*FleetApi* | [**fleetDeleteVehicleDelete**](docs/FleetApi.md#fleetDeleteVehicleDelete) | **DELETE** /Fleet/DeleteVehicle | Delete a vehicle from the fleet.  Requires the &#39;ManageFleet&#39; permission.
*FleetApi* | [**fleetGetVehicleByIdGet**](docs/FleetApi.md#fleetGetVehicleByIdGet) | **GET** /Fleet/GetVehicleById | Get a particular vehicle.  Does not require any special permission.
*FleetApi* | [**fleetGetVehiclesGet**](docs/FleetApi.md#fleetGetVehiclesGet) | **GET** /Fleet/GetVehicles | Get a collection of vehicles that are under your organisation.    Does not require any special permission.
*FleetApi* | [**fleetUpdateVehiclePut**](docs/FleetApi.md#fleetUpdateVehiclePut) | **PUT** /Fleet/UpdateVehicle | Update a vehicle.    Requires the &#39;ManageFleet&#39; permission.
*GeoFencingApi* | [**geoFencingCreateGeofencePost**](docs/GeoFencingApi.md#geoFencingCreateGeofencePost) | **POST** /GeoFencing/CreateGeofence | Create a geofencing with rules to be used for clock on/off automation.  Requires the &#39;ManageGeofencing&#39; permission.
*GeoFencingApi* | [**geoFencingDeleteGeofenceDelete**](docs/GeoFencingApi.md#geoFencingDeleteGeofenceDelete) | **DELETE** /GeoFencing/DeleteGeofence | Deletes a geofence.  Requires the &#39;ManageGeofencing&#39; permission.
*GeoFencingApi* | [**geoFencingGetGeofenceByIdGet**](docs/GeoFencingApi.md#geoFencingGetGeofenceByIdGet) | **GET** /GeoFencing/GetGeofenceById | Get a geofence by ID  Requires the &#39;SubmitTimesheets&#39; permission.
*GeoFencingApi* | [**geoFencingGetGeofencesBasicInfoGet**](docs/GeoFencingApi.md#geoFencingGetGeofencesBasicInfoGet) | **GET** /GeoFencing/GetGeofencesBasicInfo | Gets a list of all geofences in your organisation, including just the name and ID.
*GeoFencingApi* | [**geoFencingGetGeofencesGet**](docs/GeoFencingApi.md#geoFencingGetGeofencesGet) | **GET** /GeoFencing/GetGeofences | Get geofences belonging to your organisation  Requires the &#39;SubmitTimesheets&#39; permission.
*GeoFencingApi* | [**geoFencingUpdateGeofencePut**](docs/GeoFencingApi.md#geoFencingUpdateGeofencePut) | **PUT** /GeoFencing/UpdateGeofence | Updates a geofencing with rules to be used for clock on/off automation.  Requires the &#39;ManageGeofencing&#39; permission.
*JobCodesApi* | [**jobCodesCreateJobCodePost**](docs/JobCodesApi.md#jobCodesCreateJobCodePost) | **POST** /JobCodes/CreateJobCode | Create a job code.    Requires the &#39;ManageJobsAndTask&#39; permission.
*JobCodesApi* | [**jobCodesDeleteJobCodeDelete**](docs/JobCodesApi.md#jobCodesDeleteJobCodeDelete) | **DELETE** /JobCodes/DeleteJobCode | Delete a job code.    Requires the &#39;ManageJobsAndTask&#39; permission.
*JobCodesApi* | [**jobCodesGetJobCodeByIdGet**](docs/JobCodesApi.md#jobCodesGetJobCodeByIdGet) | **GET** /JobCodes/GetJobCodeById | Get a particular job code by job code id.    Requires &#39;SubmitTimesheets&#39; or &#39;ManageJobsAndTasks&#39; permissions.
*JobCodesApi* | [**jobCodesGetJobCodesGet**](docs/JobCodesApi.md#jobCodesGetJobCodesGet) | **GET** /JobCodes/GetJobCodes | Get job codes for your organisation.    Requires &#39;SubmitTimesheets&#39; or &#39;ManageJobsAndTasks&#39; permissions.
*JobCodesApi* | [**jobCodesUpdateJobCodePut**](docs/JobCodesApi.md#jobCodesUpdateJobCodePut) | **PUT** /JobCodes/UpdateJobCode | Update a job code.    Requires the &#39;ManageJobsAndTask&#39; permission.
*NFCCodesApi* | [**nFCCodesCreateNFCCodePost**](docs/NFCCodesApi.md#nFCCodesCreateNFCCodePost) | **POST** /NFCCodes/CreateNFCCode | Create a NFC codes with rules to be used for clock on/off automation.  Requires the &#39;ManageNFCCodes&#39; permission.
*NFCCodesApi* | [**nFCCodesDeleteNFCCodeDelete**](docs/NFCCodesApi.md#nFCCodesDeleteNFCCodeDelete) | **DELETE** /NFCCodes/DeleteNFCCode | Deletes a NFC code.  Requires the &#39;ManageNFCCodes&#39; permission.
*NFCCodesApi* | [**nFCCodesGetNFCCodeByIdGet**](docs/NFCCodesApi.md#nFCCodesGetNFCCodeByIdGet) | **GET** /NFCCodes/GetNFCCodeById | Get a NFC code by ID  Requires the &#39;SubmitTimesheets&#39; permission.
*NFCCodesApi* | [**nFCCodesGetNFCCodesBasicInfoGet**](docs/NFCCodesApi.md#nFCCodesGetNFCCodesBasicInfoGet) | **GET** /NFCCodes/GetNFCCodesBasicInfo | Gets a list of all NFC codes in your organisation, including just the name and ID.
*NFCCodesApi* | [**nFCCodesGetNFCCodesGet**](docs/NFCCodesApi.md#nFCCodesGetNFCCodesGet) | **GET** /NFCCodes/GetNFCCodes | Get NFC codes belonging to your organisation  Requires the &#39;SubmitTimesheets&#39; permission.
*NFCCodesApi* | [**nFCCodesUpdateNFCCodePut**](docs/NFCCodesApi.md#nFCCodesUpdateNFCCodePut) | **PUT** /NFCCodes/UpdateNFCCode | Updates a NFC code with rules to be used for clock on/off automation.  Requires the &#39;ManageNFCCodes&#39; permission.
*OrganisationApi* | [**organisationGetEditTimesheetsOutsideTodayGet**](docs/OrganisationApi.md#organisationGetEditTimesheetsOutsideTodayGet) | **GET** /Organisation/GetEditTimesheetsOutsideToday | Gets the setting for your organisation for editing timesheets outside of current work day.    Requires &#39;SubmitTimesheets&#39; permission.
*OrganisationApi* | [**organisationGetOrganisationGet**](docs/OrganisationApi.md#organisationGetOrganisationGet) | **GET** /Organisation/GetOrganisation | Get your organisation.    Requires &#39;OrganisationAdmin&#39; permission.
*OrganisationApi* | [**organisationUpdateOrganisationPut**](docs/OrganisationApi.md#organisationUpdateOrganisationPut) | **PUT** /Organisation/UpdateOrganisation | Update an organisation.    Requires &#39;OrganisationAdmin&#39; permission.
*OrganisationGroupUsersApi* | [**organisationGroupUsersGetOrganisationGroupUsersGet**](docs/OrganisationGroupUsersApi.md#organisationGroupUsersGetOrganisationGroupUsersGet) | **GET** /OrganisationGroupUsers/GetOrganisationGroupUsers | Get a collection of organisation group users that belong to an organisation group.    Requires the &#39;ManageOrganisationGroups&#39; or &#39;ManageOrganisationUsers&#39; permissions.
*OrganisationGroupUsersApi* | [**organisationGroupUsersUpdateOrganisationGroupUsersPut**](docs/OrganisationGroupUsersApi.md#organisationGroupUsersUpdateOrganisationGroupUsersPut) | **PUT** /OrganisationGroupUsers/UpdateOrganisationGroupUsers | Set the users who belong to an organisation group.    Requires the &#39;ManageOrganisationGroups&#39; permissions.
*OrganisationGroupsApi* | [**organisationGroupsCreateOrganisationGroupPost**](docs/OrganisationGroupsApi.md#organisationGroupsCreateOrganisationGroupPost) | **POST** /OrganisationGroups/CreateOrganisationGroup | Create an organisation group.    Requires the &#39;ManageOrganisationGroups&#39; permissions.
*OrganisationGroupsApi* | [**organisationGroupsDeleteOrganisationGroupDelete**](docs/OrganisationGroupsApi.md#organisationGroupsDeleteOrganisationGroupDelete) | **DELETE** /OrganisationGroups/DeleteOrganisationGroup | 
*OrganisationGroupsApi* | [**organisationGroupsGetOrganisationGroupGet**](docs/OrganisationGroupsApi.md#organisationGroupsGetOrganisationGroupGet) | **GET** /OrganisationGroups/GetOrganisationGroup | Get a particular organisation group.    Requires the &#39;ManageOrganisationGroups&#39;, &#39;ManageJobsAndTask&#39;, &#39;ManageClientsAndProjects&#39; or &#39;ManageOrganisationUsers&#39; permissions.
*OrganisationGroupsApi* | [**organisationGroupsGetOrganisationGroupsForJobGet**](docs/OrganisationGroupsApi.md#organisationGroupsGetOrganisationGroupsForJobGet) | **GET** /OrganisationGroups/GetOrganisationGroupsForJob | Get org groups for a particular job.    Requires the &#39;ManageOrganisationGroups&#39;, &#39;ManageJobsAndTask&#39;, &#39;ManageClientsAndProjects&#39; or &#39;ManageOrganisationUsers&#39; permissions.
*OrganisationGroupsApi* | [**organisationGroupsGetOrganisationGroupsForVehicleGet**](docs/OrganisationGroupsApi.md#organisationGroupsGetOrganisationGroupsForVehicleGet) | **GET** /OrganisationGroups/GetOrganisationGroupsForVehicle | Get org groups for a particular vehicle.    Requires the &#39;ManageOrganisationGroups&#39;, &#39;ManageFleet&#39; or &#39;ManageOrganisationUsers&#39; permissions.
*OrganisationGroupsApi* | [**organisationGroupsGetOrganisationGroupsGet**](docs/OrganisationGroupsApi.md#organisationGroupsGetOrganisationGroupsGet) | **GET** /OrganisationGroups/GetOrganisationGroups | Get a collection of organisation groups that are under your organisation.    Requires the &#39;ManageOrganisationGroups&#39;, &#39;ManageJobsAndTask&#39;, &#39;ManageClientsAndProjects&#39; or &#39;ManageOrganisationUsers&#39; permissions.
*OrganisationGroupsApi* | [**organisationGroupsUpdateOrganisationGroupPut**](docs/OrganisationGroupsApi.md#organisationGroupsUpdateOrganisationGroupPut) | **PUT** /OrganisationGroups/UpdateOrganisationGroup | Update an organisation group.    Requires the &#39;ManageOrganisationGroups&#39; permissions.
*ProjectsApi* | [**projectsCreateProjectPost**](docs/ProjectsApi.md#projectsCreateProjectPost) | **POST** /Projects/CreateProject | Create a project.    Requires the &#39;ManageClientsAndProjects&#39; permission.
*ProjectsApi* | [**projectsGetProjectByIdGet**](docs/ProjectsApi.md#projectsGetProjectByIdGet) | **GET** /Projects/GetProjectById | Get a project by its Id.    Requires the &#39;ManageClientsAndProjects&#39; or &#39;ManageJobsAndTask&#39; permissions.
*ProjectsApi* | [**projectsGetProjectsForClientGet**](docs/ProjectsApi.md#projectsGetProjectsForClientGet) | **GET** /Projects/GetProjectsForClient | Get projects for a particular client.    Requires the &#39;ManageClientsAndProjects&#39; or &#39;ManageJobsAndTask&#39; permissions.
*ProjectsApi* | [**projectsUpdateProjectPut**](docs/ProjectsApi.md#projectsUpdateProjectPut) | **PUT** /Projects/UpdateProject | Update a project.    Requires the &#39;ManageClientsAndProjects&#39; permission.
*QRCodesApi* | [**qRCodesCreateQRCodePost**](docs/QRCodesApi.md#qRCodesCreateQRCodePost) | **POST** /QRCodes/CreateQRCode | Create a QR codes with rules to be used for clock on/off automation.  Requires the &#39;ManageQRCodes&#39; permission.
*QRCodesApi* | [**qRCodesDeleteQRCodeDelete**](docs/QRCodesApi.md#qRCodesDeleteQRCodeDelete) | **DELETE** /QRCodes/DeleteQRCode | Deletes a QR code.  Requires the &#39;ManageQRCodes&#39; permission.
*QRCodesApi* | [**qRCodesGetQRCodeByIdGet**](docs/QRCodesApi.md#qRCodesGetQRCodeByIdGet) | **GET** /QRCodes/GetQRCodeById | Get a QR code by ID  Requires the &#39;SubmitTimesheets&#39; permission.
*QRCodesApi* | [**qRCodesGetQRCodesBasicInfoGet**](docs/QRCodesApi.md#qRCodesGetQRCodesBasicInfoGet) | **GET** /QRCodes/GetQRCodesBasicInfo | Gets a list of all QR codes in your organisation, including just the name and ID.
*QRCodesApi* | [**qRCodesGetQRCodesGet**](docs/QRCodesApi.md#qRCodesGetQRCodesGet) | **GET** /QRCodes/GetQRCodes | Get QR codes belonging to your organisation  Requires the &#39;SubmitTimesheets&#39; permission.
*QRCodesApi* | [**qRCodesUpdateQRCodePut**](docs/QRCodesApi.md#qRCodesUpdateQRCodePut) | **PUT** /QRCodes/UpdateQRCode | Updates a QR code with rules to be used for clock on/off automation.  Requires the &#39;ManageQRCodes&#39; permission.
*ReportsApi* | [**reportsGetAllChartsDataAdminGet**](docs/ReportsApi.md#reportsGetAllChartsDataAdminGet) | **GET** /Reports/GetAllChartsDataAdmin | Get Consolidated Admin Reports Data (Jobs, Tasks, Clients and Projects).  These are the organisation wide reports, with data from potentially all employees.    Requires the &#39;ReportAdmin&#39; permission.
*ReportsApi* | [**reportsGetAllChartsDataUserGet**](docs/ReportsApi.md#reportsGetAllChartsDataUserGet) | **GET** /Reports/GetAllChartsDataUser | Get Consolidated User Reports Data (Jobs, Tasks, Clients and Projects).  These are the user&#39;s own reports.    Requires the &#39;ViewOwnReports&#39; permission.
*ReportsApi* | [**reportsGetFleetSummaryAdminGet**](docs/ReportsApi.md#reportsGetFleetSummaryAdminGet) | **GET** /Reports/GetFleetSummaryAdmin | Gets a summary report, which includes total distance travelled and total running costs, for vehicles within your organisation  Requires the &#39;ReportAdmin&#39; permission.
*ReportsApi* | [**reportsGetOrgTripByIdGet**](docs/ReportsApi.md#reportsGetOrgTripByIdGet) | **GET** /Reports/GetOrgTripById | Get trip by Id, for reporting purposes.    Requires the &#39;ReportAdmin&#39; permission.
*ReportsApi* | [**reportsGetOrganisationTimesheetFileAttachmentsGet**](docs/ReportsApi.md#reportsGetOrganisationTimesheetFileAttachmentsGet) | **GET** /Reports/GetOrganisationTimesheetFileAttachments | Reports on Organisation timesheet file attachments (files uploaded and attached to timesheet records)  Requires the &#39;ReportAdmin&#39; permission.
*ReportsApi* | [**reportsGetOrganisationTranscriptsGet**](docs/ReportsApi.md#reportsGetOrganisationTranscriptsGet) | **GET** /Reports/GetOrganisationTranscripts | Reports on Organisation transcripts (When an audio file is attached, it will be automatically transcribed, these are the transcriptions)    Requires the &#39;ReportAdmin&#39; permission.
*ReportsApi* | [**reportsGetOrganisationTripsGet**](docs/ReportsApi.md#reportsGetOrganisationTripsGet) | **GET** /Reports/GetOrganisationTrips | Reports on Organisation trips (GPS tracking from whole organisation).    Requires the &#39;ReportAdmin&#39; permission.
*ReportsApi* | [**reportsGetRawDataAdminGet**](docs/ReportsApi.md#reportsGetRawDataAdminGet) | **GET** /Reports/GetRawDataAdmin | Get Timesheets Raw Data.  This data details each timesheet record.  These are the organisation wide timesheet records, with data from potentially all employees.    Requires the &#39;ReportAdmin&#39; permission.
*ReportsApi* | [**reportsProjectCostingsAdminGet**](docs/ReportsApi.md#reportsProjectCostingsAdminGet) | **GET** /Reports/ProjectCostingsAdmin | Gets project cost estimations VS actual cost for date range and users.    Requires the &#39;ReportAdmin&#39; permission.
*ReportsApi* | [**reportsUserJobsOverTimeGet**](docs/ReportsApi.md#reportsUserJobsOverTimeGet) | **GET** /Reports/UserJobsOverTime | Timeseries jobs data for the logged in user.    Requires the &#39;ViewOwnReports&#39; or &#39;SubmitTimesheets&#39;.
*TasksApi* | [**tasksCreateTaskPost**](docs/TasksApi.md#tasksCreateTaskPost) | **POST** /Tasks/CreateTask | Create a task.    Requires the &#39;ManageJobsAndTask&#39; permission.
*TasksApi* | [**tasksDeleteTaskDelete**](docs/TasksApi.md#tasksDeleteTaskDelete) | **DELETE** /Tasks/DeleteTask | Delete a task.    Requires the &#39;ManageJobsAndTask&#39; permission.
*TasksApi* | [**tasksGetTaskByIdGet**](docs/TasksApi.md#tasksGetTaskByIdGet) | **GET** /Tasks/GetTaskById | Get a particular task by Id.   Requires the &#39;SubmitTimesheets&#39; or &#39;ManageJobsAndTask&#39; permissions.
*TasksApi* | [**tasksGetTasksForJobGet**](docs/TasksApi.md#tasksGetTasksForJobGet) | **GET** /Tasks/GetTasksForJob | Get a collection of tasks for a particular Job, specified by JobId.    Requires the &#39;SubmitTimesheets&#39; or &#39;ManageJobsAndTask&#39; permissions.
*TasksApi* | [**tasksGetTasksGet**](docs/TasksApi.md#tasksGetTasksGet) | **GET** /Tasks/GetTasks | Get tasks in your organisation.   Requires the &#39;SubmitTimesheets&#39; or &#39;ManageJobsAndTask&#39; permissions.
*TasksApi* | [**tasksUpdateTaskPut**](docs/TasksApi.md#tasksUpdateTaskPut) | **PUT** /Tasks/UpdateTask | Update a task.    Requires the &#39;ManageJobsAndTask&#39; permission.
*TimesheetAutomationApi* | [**timesheetAutomationCreateAutomationStepPost**](docs/TimesheetAutomationApi.md#timesheetAutomationCreateAutomationStepPost) | **POST** /TimesheetAutomation/CreateAutomationStep | Creates an automation step.  Timesheet automation is determined by looking at steps taken by the user.  Create a step to log some automation action, such as entering a geofence, scanning a QR Code or tapping on an NFC badge.  Requires the &#39;SubmitTimesheets&#39; permission.
*TimesheetAutomationApi* | [**timesheetAutomationGetTimesheetAutomationGeofenceAuditTrailGet**](docs/TimesheetAutomationApi.md#timesheetAutomationGetTimesheetAutomationGeofenceAuditTrailGet) | **GET** /TimesheetAutomation/GetTimesheetAutomationGeofenceAuditTrail | Retrieve the timesheet automation / alerts for geofences activities  Requires the &#39;ManageGeofencing&#39; permission.
*TimesheetAutomationApi* | [**timesheetAutomationGetTimesheetAutomationNFCTagAuditTrailGet**](docs/TimesheetAutomationApi.md#timesheetAutomationGetTimesheetAutomationNFCTagAuditTrailGet) | **GET** /TimesheetAutomation/GetTimesheetAutomationNFCTagAuditTrail | Retrieve the timesheet automation / alerts for NFC tag activities  Requires the &#39;ManageNFCCodes&#39; permission.
*TimesheetAutomationApi* | [**timesheetAutomationGetTimesheetAutomationQRCodeAuditTrailGet**](docs/TimesheetAutomationApi.md#timesheetAutomationGetTimesheetAutomationQRCodeAuditTrailGet) | **GET** /TimesheetAutomation/GetTimesheetAutomationQRCodeAuditTrail | Retrieve the timesheet automation / alerts for QR Code activities  Requires the &#39;ManageQRCodes&#39; permission.
*TimesheetsApi* | [**timesheetsCreateSingleTimesheetPost**](docs/TimesheetsApi.md#timesheetsCreateSingleTimesheetPost) | **POST** /Timesheets/CreateSingleTimesheet | Inserts a single timesheet record.    Requires the &#39;SubmitTimesheets&#39; permission.
*TimesheetsApi* | [**timesheetsDeleteTimesheetDelete**](docs/TimesheetsApi.md#timesheetsDeleteTimesheetDelete) | **DELETE** /Timesheets/DeleteTimesheet | Delete a timesheet.    Requires the &#39;SubmitTimesheets&#39; permission.
*TimesheetsApi* | [**timesheetsGetTimesheetsGet**](docs/TimesheetsApi.md#timesheetsGetTimesheetsGet) | **GET** /Timesheets/GetTimesheets | Get timesheets between start and end dates.  Note: the date range cannot exceed 24 hours.  This method is generally used to get timesheets for a particular day.    Requires the &#39;SubmitTimesheets&#39; permission.
*TimesheetsApi* | [**timesheetsUpdateTimesheetsPut**](docs/TimesheetsApi.md#timesheetsUpdateTimesheetsPut) | **PUT** /Timesheets/UpdateTimesheets | Batch update timesheets.    Requires the &#39;SubmitTimesheets&#39; permission.
*TranscriptsApi* | [**transcriptsGetMyTranscriptGet**](docs/TranscriptsApi.md#transcriptsGetMyTranscriptGet) | **GET** /Transcripts/GetMyTranscript | Get an audio to text transcript for a particular audio file attachment
*TranscriptsApi* | [**transcriptsGetMyTranscriptsGet**](docs/TranscriptsApi.md#transcriptsGetMyTranscriptsGet) | **GET** /Transcripts/GetMyTranscripts | Get my file transcripts.  Get audio to text transcripts that you&#39;ve created.
*TripsApi* | [**tripsCreateTripPost**](docs/TripsApi.md#tripsCreateTripPost) | **POST** /Trips/CreateTrip | Create a new trip.  Important: create a timesheet record before calling this, passing in the new timesheet record id as a reference.    Requires the &#39;SubmitTimesheets&#39; permission.
*TripsApi* | [**tripsGetMyTripByIdGet**](docs/TripsApi.md#tripsGetMyTripByIdGet) | **GET** /Trips/GetMyTripById | Get trip by Id.    Requires the &#39;ViewMyTrips&#39; permission.
*TripsApi* | [**tripsGetMyTripsGet**](docs/TripsApi.md#tripsGetMyTripsGet) | **GET** /Trips/GetMyTrips | Get my trips.  Get the GPS trips you&#39;ve recorded and submitted.    Requires the &#39;ViewMyTrips&#39; permission.
*UserJobFavouritesApi* | [**userJobFavouritesCreateJobFavouritePost**](docs/UserJobFavouritesApi.md#userJobFavouritesCreateJobFavouritePost) | **POST** /UserJobFavourites/CreateJobFavourite | Create a job favourite.    Requires the &#39;SubmitTimesheets&#39; permission.
*UserJobFavouritesApi* | [**userJobFavouritesDeleteJobFavouriteDelete**](docs/UserJobFavouritesApi.md#userJobFavouritesDeleteJobFavouriteDelete) | **DELETE** /UserJobFavourites/DeleteJobFavourite | Delete a job favourite.    Requires the &#39;SubmitTimesheets&#39; permission.
*UserJobFavouritesApi* | [**userJobFavouritesGetJobFavouritesGet**](docs/UserJobFavouritesApi.md#userJobFavouritesGetJobFavouritesGet) | **GET** /UserJobFavourites/GetJobFavourites | Get your job favourites.    Requires the &#39;SubmitTimesheets&#39; permission.
*UserPayRatesApi* | [**userPayRatesCreatePayRatePost**](docs/UserPayRatesApi.md#userPayRatesCreatePayRatePost) | **POST** /UserPayRates/CreatePayRate | Create a new pay rate for a particular user, archiving the previous pay rate.    Requires the &#39;ManageOrganisationUsers&#39; permission.
*UserPayRatesApi* | [**userPayRatesGetPayRatesGet**](docs/UserPayRatesApi.md#userPayRatesGetPayRatesGet) | **GET** /UserPayRates/GetPayRates | Get a collection of pay rates for a particular user, specified by user id.    Requires the &#39;ManageOrganisationUsers&#39; permission.
*UserProfileApi* | [**userProfileDoLoginPut**](docs/UserProfileApi.md#userProfileDoLoginPut) | **PUT** /UserProfile/DoLogin | Login to your ChronoSheets account and obtain an Auth Token which you can use for other ChronoSheets API methods.    Does not require any special permissions.
*UserProfileApi* | [**userProfileDoLogoutDelete**](docs/UserProfileApi.md#userProfileDoLogoutDelete) | **DELETE** /UserProfile/DoLogout | Logout of your ChronoSheets account.  This method ends and deletes your active session.    Does not require any special permissions.
*UserProfileApi* | [**userProfileGetMyProfileGet**](docs/UserProfileApi.md#userProfileGetMyProfileGet) | **GET** /UserProfile/GetMyProfile | Get your own profile.  Use this method to obtain detailed information about your ChronoSheets user profile.    Does not require any special permissions.
*UserProfileApi* | [**userProfileKeepSessionAliveGet**](docs/UserProfileApi.md#userProfileKeepSessionAliveGet) | **GET** /UserProfile/KeepSessionAlive | Keep a session alive.  Use this method to keep a session active.  You could use this to &#39;ping&#39; ChronoSheets every &#39;x&#39; minutes to make sure your Auth Token will keep working.    Does not require any special permissions.
*UserProfileApi* | [**userProfileUpdateMyProfilePut**](docs/UserProfileApi.md#userProfileUpdateMyProfilePut) | **PUT** /UserProfile/UpdateMyProfile | Update your own profile.  Use this method to update your profile information or update/change your password.    Does not require any special permissions.
*UsersApi* | [**usersCreateTimesheetUserPost**](docs/UsersApi.md#usersCreateTimesheetUserPost) | **POST** /Users/CreateTimesheetUser | Create a user account in your organisation.  Requires the &#39;ManageOrganisationUsers&#39; permission.
*UsersApi* | [**usersGetTimesheetUserGet**](docs/UsersApi.md#usersGetTimesheetUserGet) | **GET** /Users/GetTimesheetUser | Get a particular user in your organisation.  Requires the &#39;ManageOrganisationUsers&#39; or &#39;ManageOrganisationGroups&#39; permissions.
*UsersApi* | [**usersGetTimesheetUsersGet**](docs/UsersApi.md#usersGetTimesheetUsersGet) | **GET** /Users/GetTimesheetUsers | Get users accounts in your organisation.  Requires the &#39;ManageOrganisationUsers&#39; or &#39;ManageOrganisationGroups&#39; permissions.
*UsersApi* | [**usersUpdateTimesheetUserPut**](docs/UsersApi.md#usersUpdateTimesheetUserPut) | **PUT** /Users/UpdateTimesheetUser | Update a user account.  Requires the &#39;ManageOrganisationUsers&#39; permission.
*UsualHoursApi* | [**usualHoursGetUsualHoursGet**](docs/UsualHoursApi.md#usualHoursGetUsualHoursGet) | **GET** /UsualHours/GetUsualHours | Get usual hours (rostered hours) for an employee.  Requires the &#39;ManageOrganisationUsers&#39; permission.
*UsualHoursApi* | [**usualHoursSetUsualHoursPut**](docs/UsualHoursApi.md#usualHoursSetUsualHoursPut) | **PUT** /UsualHours/SetUsualHours | Set usual hours (rostered hours) for an employee.  Requires the &#39;ManageOrganisationUsers&#39; permission.


## Documentation for Models

 - [AggregateClient](docs/AggregateClient.md)
 - [AggregateClientListApiResponse](docs/AggregateClientListApiResponse.md)
 - [AggregateJobCode](docs/AggregateJobCode.md)
 - [AggregateJobCodeListApiResponse](docs/AggregateJobCodeListApiResponse.md)
 - [AggregateJobTask](docs/AggregateJobTask.md)
 - [AggregateProject](docs/AggregateProject.md)
 - [ApiResponseCode](docs/ApiResponseCode.md)
 - [AudioMediaTypes](docs/AudioMediaTypes.md)
 - [AutomationAuditDataSortColumns](docs/AutomationAuditDataSortColumns.md)
 - [BasicCoordinate](docs/BasicCoordinate.md)
 - [BasicGeofence](docs/BasicGeofence.md)
 - [BasicGeofenceListApiResponseForPaginated](docs/BasicGeofenceListApiResponseForPaginated.md)
 - [BasicNFCCode](docs/BasicNFCCode.md)
 - [BasicNFCCodeListApiResponseForPaginated](docs/BasicNFCCodeListApiResponseForPaginated.md)
 - [BasicQRCode](docs/BasicQRCode.md)
 - [BasicQRCodeListApiResponseForPaginated](docs/BasicQRCodeListApiResponseForPaginated.md)
 - [BatchUpdateTimesheetRequest](docs/BatchUpdateTimesheetRequest.md)
 - [BooleanApiResponse](docs/BooleanApiResponse.md)
 - [Client](docs/Client.md)
 - [ClientApiResponse](docs/ClientApiResponse.md)
 - [ClientListApiResponse](docs/ClientListApiResponse.md)
 - [ClientSeriesReportItem](docs/ClientSeriesReportItem.md)
 - [ClientSideUser](docs/ClientSideUser.md)
 - [ClientTotalsReportItem](docs/ClientTotalsReportItem.md)
 - [CombinedReportsData](docs/CombinedReportsData.md)
 - [CombinedReportsDataApiResponse](docs/CombinedReportsDataApiResponse.md)
 - [CreateAutomationStepRequest](docs/CreateAutomationStepRequest.md)
 - [CreateGeoFenceRequest](docs/CreateGeoFenceRequest.md)
 - [CreateNFCCodeRequest](docs/CreateNFCCodeRequest.md)
 - [CreateQRCodeRequest](docs/CreateQRCodeRequest.md)
 - [CreateTripRequest](docs/CreateTripRequest.md)
 - [DoLoginRequest](docs/DoLoginRequest.md)
 - [DoLoginResponse](docs/DoLoginResponse.md)
 - [DoLoginResponseApiResponse](docs/DoLoginResponseApiResponse.md)
 - [ExtendedGeofence](docs/ExtendedGeofence.md)
 - [ExtendedGeofenceListApiResponseForPaginated](docs/ExtendedGeofenceListApiResponseForPaginated.md)
 - [ExtendedNFCCode](docs/ExtendedNFCCode.md)
 - [ExtendedNFCCodeListApiResponseForPaginated](docs/ExtendedNFCCodeListApiResponseForPaginated.md)
 - [ExtendedQRCode](docs/ExtendedQRCode.md)
 - [ExtendedQRCodeListApiResponseForPaginated](docs/ExtendedQRCodeListApiResponseForPaginated.md)
 - [FileAttachmentTypes](docs/FileAttachmentTypes.md)
 - [FleetSummaryReportItem](docs/FleetSummaryReportItem.md)
 - [FleetSummaryReportItemListApiResponse](docs/FleetSummaryReportItemListApiResponse.md)
 - [FleetVehicle](docs/FleetVehicle.md)
 - [FleetVehicleApiResponse](docs/FleetVehicleApiResponse.md)
 - [FleetVehicleListApiResponse](docs/FleetVehicleListApiResponse.md)
 - [ForcedReportFromAllReports](docs/ForcedReportFromAllReports.md)
 - [Geofence](docs/Geofence.md)
 - [GeofenceApiResponse](docs/GeofenceApiResponse.md)
 - [InsertClientRequest](docs/InsertClientRequest.md)
 - [InsertJobCodeRequest](docs/InsertJobCodeRequest.md)
 - [InsertOrganisationGroupRequest](docs/InsertOrganisationGroupRequest.md)
 - [InsertProjectRequest](docs/InsertProjectRequest.md)
 - [InsertTaskRequest](docs/InsertTaskRequest.md)
 - [InsertUserHourlyRateRequest](docs/InsertUserHourlyRateRequest.md)
 - [InsertUserJobFavouriteRequest](docs/InsertUserJobFavouriteRequest.md)
 - [InsertUserRequest](docs/InsertUserRequest.md)
 - [InsertUserResponse](docs/InsertUserResponse.md)
 - [InsertUserResponseApiResponse](docs/InsertUserResponseApiResponse.md)
 - [InsertVehicleRequest](docs/InsertVehicleRequest.md)
 - [Int32ApiResponse](docs/Int32ApiResponse.md)
 - [Int32ListApiResponse](docs/Int32ListApiResponse.md)
 - [JobCode](docs/JobCode.md)
 - [JobCodeApiResponse](docs/JobCodeApiResponse.md)
 - [JobCodeListApiResponse](docs/JobCodeListApiResponse.md)
 - [JobSeriesReportItem](docs/JobSeriesReportItem.md)
 - [JobSeriesReportItemListApiResponse](docs/JobSeriesReportItemListApiResponse.md)
 - [JobTotalsReportItem](docs/JobTotalsReportItem.md)
 - [MobilePlatforms](docs/MobilePlatforms.md)
 - [NFCCode](docs/NFCCode.md)
 - [NFCCodeApiResponse](docs/NFCCodeApiResponse.md)
 - [OrgReportTimesheetFileAttachment](docs/OrgReportTimesheetFileAttachment.md)
 - [OrgReportTimesheetFileAttachmentListApiResponseForPaginated](docs/OrgReportTimesheetFileAttachmentListApiResponseForPaginated.md)
 - [OrgReportTranscript](docs/OrgReportTranscript.md)
 - [OrgReportTranscriptListApiResponseForPaginated](docs/OrgReportTranscriptListApiResponseForPaginated.md)
 - [OrgReportTrip](docs/OrgReportTrip.md)
 - [OrgReportTripListApiResponseForPaginated](docs/OrgReportTripListApiResponseForPaginated.md)
 - [Organisation](docs/Organisation.md)
 - [OrganisationApiResponse](docs/OrganisationApiResponse.md)
 - [OrganisationGroup](docs/OrganisationGroup.md)
 - [OrganisationGroupApiResponse](docs/OrganisationGroupApiResponse.md)
 - [OrganisationGroupListApiResponse](docs/OrganisationGroupListApiResponse.md)
 - [OrganisationPricingPlan](docs/OrganisationPricingPlan.md)
 - [Project](docs/Project.md)
 - [ProjectApiResponse](docs/ProjectApiResponse.md)
 - [ProjectCostingReportItem](docs/ProjectCostingReportItem.md)
 - [ProjectCostingReportItemListApiResponse](docs/ProjectCostingReportItemListApiResponse.md)
 - [ProjectListApiResponse](docs/ProjectListApiResponse.md)
 - [ProjectSeriesReportItem](docs/ProjectSeriesReportItem.md)
 - [ProjectTotalsReportItem](docs/ProjectTotalsReportItem.md)
 - [QRCode](docs/QRCode.md)
 - [QRCodeApiResponse](docs/QRCodeApiResponse.md)
 - [RawDataSortColumns](docs/RawDataSortColumns.md)
 - [RawReportItem](docs/RawReportItem.md)
 - [RawReportItemListApiResponseForPaginated](docs/RawReportItemListApiResponseForPaginated.md)
 - [SaveClientRequest](docs/SaveClientRequest.md)
 - [SaveOrganisationGroupRequest](docs/SaveOrganisationGroupRequest.md)
 - [SaveVehicleRequest](docs/SaveVehicleRequest.md)
 - [SetOrganisationGroupUsersRequest](docs/SetOrganisationGroupUsersRequest.md)
 - [SetUsualHoursRequest](docs/SetUsualHoursRequest.md)
 - [SignUpSource](docs/SignUpSource.md)
 - [SortDirection](docs/SortDirection.md)
 - [SubscriptionSource](docs/SubscriptionSource.md)
 - [TaskSeriesReportItem](docs/TaskSeriesReportItem.md)
 - [TaskTotalsReportItem](docs/TaskTotalsReportItem.md)
 - [TimeSlot](docs/TimeSlot.md)
 - [Timesheet](docs/Timesheet.md)
 - [TimesheetAutomationAction](docs/TimesheetAutomationAction.md)
 - [TimesheetAutomationGeofenceAlertSettings](docs/TimesheetAutomationGeofenceAlertSettings.md)
 - [TimesheetAutomationGeofenceTriggerSettings](docs/TimesheetAutomationGeofenceTriggerSettings.md)
 - [TimesheetAutomationNFCCodeAlertSettings](docs/TimesheetAutomationNFCCodeAlertSettings.md)
 - [TimesheetAutomationNFCCodeTriggerSettings](docs/TimesheetAutomationNFCCodeTriggerSettings.md)
 - [TimesheetAutomationQRCodeAlertSettings](docs/TimesheetAutomationQRCodeAlertSettings.md)
 - [TimesheetAutomationQRCodeTriggerSettings](docs/TimesheetAutomationQRCodeTriggerSettings.md)
 - [TimesheetAutomationWithOrgAndGeofence](docs/TimesheetAutomationWithOrgAndGeofence.md)
 - [TimesheetAutomationWithOrgAndGeofenceListApiResponseForPaginated](docs/TimesheetAutomationWithOrgAndGeofenceListApiResponseForPaginated.md)
 - [TimesheetAutomationWithOrgAndNFCCode](docs/TimesheetAutomationWithOrgAndNFCCode.md)
 - [TimesheetAutomationWithOrgAndNFCCodeListApiResponseForPaginated](docs/TimesheetAutomationWithOrgAndNFCCodeListApiResponseForPaginated.md)
 - [TimesheetAutomationWithOrgAndQRCode](docs/TimesheetAutomationWithOrgAndQRCode.md)
 - [TimesheetAutomationWithOrgAndQRCodeListApiResponseForPaginated](docs/TimesheetAutomationWithOrgAndQRCodeListApiResponseForPaginated.md)
 - [TimesheetDay](docs/TimesheetDay.md)
 - [TimesheetFileAttachment](docs/TimesheetFileAttachment.md)
 - [TimesheetFileAttachmentApiResponse](docs/TimesheetFileAttachmentApiResponse.md)
 - [TimesheetFileAttachmentListApiResponseForPaginated](docs/TimesheetFileAttachmentListApiResponseForPaginated.md)
 - [TimesheetListApiResponse](docs/TimesheetListApiResponse.md)
 - [TimesheetTask](docs/TimesheetTask.md)
 - [TimesheetTaskApiResponse](docs/TimesheetTaskApiResponse.md)
 - [TimesheetTaskListApiResponse](docs/TimesheetTaskListApiResponse.md)
 - [Transcription](docs/Transcription.md)
 - [TranscriptionApiResponse](docs/TranscriptionApiResponse.md)
 - [TranscriptionJobStatus](docs/TranscriptionJobStatus.md)
 - [Trip](docs/Trip.md)
 - [TripApiResponse](docs/TripApiResponse.md)
 - [TripCoordinate](docs/TripCoordinate.md)
 - [TripListApiResponseForPaginated](docs/TripListApiResponseForPaginated.md)
 - [UpdateGeoFenceRequest](docs/UpdateGeoFenceRequest.md)
 - [UpdateJobCodeRequest](docs/UpdateJobCodeRequest.md)
 - [UpdateMyProfileRequest](docs/UpdateMyProfileRequest.md)
 - [UpdateNFCCodeRequest](docs/UpdateNFCCodeRequest.md)
 - [UpdateOrganisationRequest](docs/UpdateOrganisationRequest.md)
 - [UpdateOrganisationResponse](docs/UpdateOrganisationResponse.md)
 - [UpdateOrganisationResponseApiResponse](docs/UpdateOrganisationResponseApiResponse.md)
 - [UpdateProfileResponse](docs/UpdateProfileResponse.md)
 - [UpdateProfileResponseApiResponse](docs/UpdateProfileResponseApiResponse.md)
 - [UpdateProjectRequest](docs/UpdateProjectRequest.md)
 - [UpdateQRCodeRequest](docs/UpdateQRCodeRequest.md)
 - [UpdateTaskRequest](docs/UpdateTaskRequest.md)
 - [UpdateUserRequest](docs/UpdateUserRequest.md)
 - [UpdateUserResponse](docs/UpdateUserResponse.md)
 - [UpdateUserResponseApiResponse](docs/UpdateUserResponseApiResponse.md)
 - [UserForManagement](docs/UserForManagement.md)
 - [UserForManagementApiResponse](docs/UserForManagementApiResponse.md)
 - [UserForManagementListApiResponse](docs/UserForManagementListApiResponse.md)
 - [UserHourlyRate](docs/UserHourlyRate.md)
 - [UserHourlyRateListApiResponse](docs/UserHourlyRateListApiResponse.md)
 - [UserJobFavourite](docs/UserJobFavourite.md)
 - [UserJobFavouriteListApiResponse](docs/UserJobFavouriteListApiResponse.md)
 - [UserProfile](docs/UserProfile.md)
 - [UserProfileApiResponse](docs/UserProfileApiResponse.md)
 - [UsualHoursDay](docs/UsualHoursDay.md)
 - [UsualHoursDayListApiResponse](docs/UsualHoursDayListApiResponse.md)


## Documentation for Authorization

Authentication schemes defined for the API:
### x-chronosheets-auth

- **Type**: API key

- **API key parameter name**: x-chronosheets-auth
- **Location**: HTTP header


## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author

lachlan@chronosheets.com

